hanzo-runtime 1.1.12

Non Rust Code for Hanzo AI platform
docs.rs failed to build hanzo-runtime-1.1.12
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.